@@ -10,7 +10,7 @@ class NewsletterTemplateAdmin(admin.ModelAdmin):
 
     def rendered_view(self, obj):
         link_icon = '%simages/icons/external_16x16.png' % settings.STATIC_URL
-        link = '<a href="%s" title="%s"><img src="%s" /></a>' % (
+        link = '<a href="%s" title="%s"><img src="%s" alt="External 16x16" title="external 16x16" /></a>' % (
             obj.get_absolute_url(),
             obj,
             link_icon,
@@ -21,7 +21,7 @@ class NewsletterTemplateAdmin(admin.ModelAdmin):
 
     def content_view(self, obj):
         link_icon = '%simages/icons/external_16x16.png' % settings.STATIC_URL
-        link = '<a href="%s" title="%s"><img src="%s" /></a>' % (
+        link = '<a href="%s" title="%s"><img src="%s" alt="External 16x16" title="external 16x16" /></a>' % (
             obj.get_content_url(),
             obj,
             link_icon,
